@@ -159,23 +159,34 @@ class ResourceLocker:
         pp.pprint(req.json())
         return req
 
-    def change_queue(self, queue_id, status, description=None):
+    def change_queue(self, queue_id, status, description=None, **datakwargs):
         """
         A method to send a POST request to change the status of the queue.
+        A queue has data dictionary and some more fields that we support to modify
+            Each k&v pair that is liked to be added to queue, will be added via **datakwargs
         :return: req
         """
         final_endpoint = self.endpoints["rqueue"] + str(queue_id)
         req = requests.get(final_endpoint, headers=self.headers)
         if req.status_code == 200:
+            # Check for data dictionary args to override if needed:
+            data_section = json.loads(req.json().get('data'))
+            if datakwargs:
+                for k, v in datakwargs.items():
+                    data_section[k] = v
 
-            data = {
-                "status": status,
-            }
+            print(f"DATA SECTION: {data_section}")
+            # Modify status
+            to_modify = {"status": status}
+
+            # Modify description if provided
             if description:
-                data["description"] = description
+                to_modify["description"] = description
 
-            data_json = json.dumps(data)
+            # Modify data section
+            to_modify["data"] = data_section
 
+            data_json = json.dumps(to_modify)
             req = requests.put(final_endpoint, headers=self.headers, data=data_json)
             pp.pprint(req.json())
             return req
@@ -206,13 +217,17 @@ class ResourceLocker:
         """
         if verify_connection:
             self.check_connection()
-
         final_endpoint = self.endpoints["rqueue"] + str(queue_id)
         req = requests.get(final_endpoint, headers=self.headers)
         if req.status_code == 200:
             return req.json()
-
-        return None
+        else:
+            print(
+                f"The request for the queue returned code: {req.status_code} \n"
+                "Response was: \n"
+                f"{req.text}"
+            )
+            return None
 
     def wait_until_finished(
         self,
@@ -255,11 +270,10 @@ class ResourceLocker:
                 )
                 if not queue_to_check:
                     raise Exception(
-                        f"Queue {queue_id} does not exist on the server! \n"
+                        f"Queue {queue_id} seems to not exist on the server! \n"
                         "Error is not recoverable, raising Exception \n"
-                        "Please check the logs of the Django application! \n"
-                        "Possible solutions: \n"
-                        " - Please double check your search_string, that it matches to an existing label or name"
+                        "Please check the output of the method. \n"
+                        "Or check the logs of the Resource Locker Server! \n"
                     )
                 # Once we passed through the check if queue exists, we should check continuously it's status:
                 queue_status = queue_to_check.get("status")
@@ -288,7 +302,7 @@ class ResourceLocker:
                         else:
                             raise Exception(err_msg)
 
-                    self.beat_queue(queue_id)
+                    self.beat_queue(queue_id, suppress_logs=True)
                     time.sleep(interval)
             except ConnectionError as e:
                 print(
@@ -384,13 +398,14 @@ class ResourceLocker:
         req = requests.put(final_endpoint, headers=self.headers, data=newjson)
         return req
 
-    def beat_queue(self, queue_id):
+    def beat_queue(self, queue_id, suppress_logs=False):
         '''
         Method that will write the datetime.utcnow() to the field of
             last_beat to the queue.
         This is useful to determine if there is still alive client
             that waits for the specific queue to being FINISHED
         :param queue_id:
+        :param suppress_logs False by default, sometimes we'd like to quiet the logs
         :return:
         '''
         final_endpoint = self.endpoints["rqueue"] + str(queue_id)
@@ -404,9 +419,10 @@ class ResourceLocker:
             data_json = json.dumps(data)
 
             req = requests.put(final_endpoint, headers=self.headers, data=data_json)
-            pp.pprint(req.json())
+            if not suppress_logs:
+                pp.pprint(req.json())
             return req
 
-        print(f"Something went wrong changing {queue_id} \n")
-        pp.pprint(req.json())
-        return req
\ No newline at end of file
+        print(f"Something went wrong beating {queue_id} \n")
+        pp.pprint(req.text)
+        return req
